<?php
	// We need a textdomain for localization support,
	// with language files in the /lang folder
	load_theme_textdomain( 'simple-static', TEMPLATEPATH . '/lang' );
	
	// This is the default content width, 600 px
	if ( ! isset( $content_width ) )
		$content_width = 600;
	
	// Adding theme support for post thumbnails
	add_theme_support( 'post-thumbnails' );
	
	// Adding theme support for custom backgrounds
	add_custom_background();
	
	// Telling WordPress to use editor-style.css for the visual editor
	add_editor_style();
	
	// Adding feed links to header
	add_theme_support( 'automatic-feed-links' );

	// CUSTOM HEADER
	// -------------
	// Adding theme support for custom headers
	add_custom_image_header( '', 'simple-static_admin_header_style' );
	
	// Remove header text and null the text color
	define( 'NO_HEADER_TEXT', true );
	define( 'HEADER_TEXTCOLOR', '');
	
	// Default header image, using 'stylesheet_directory' so that
	// child themes will work
	define( 'HEADER_IMAGE', get_bloginfo('stylesheet_directory') . '/img/default-header.jpg' );
	
	// Header width and height, 920x200 px
	define( 'HEADER_IMAGE_WIDTH', 920 );
	define( 'HEADER_IMAGE_HEIGHT', 200 );

	// Adding post thumbnail support (same size as custom header images)
	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );

	// MENU AREA
	// ---------
	// Adding and defining the Menu area found in the header.php file
	register_nav_menus( array(
		'top-menu' => __( 'Top Menu', 'simple-static' ),
		'bottom-menu' => __( 'Bottom Menu', 'simple-static' )
	) );

	// WIDGET AREAS
	// ------------
	// Widget area used on the front page, on top of the header image
	register_sidebar( array(
		'name' => __( 'Header Text Blurb', 'simple-static' ),
		'id' => 'header-text-blurb',
		'description' => __( 'The blurb on top of the custom header.', 'simple-static' ),
		'before_widget' => '<div id="header-blurb"">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	// Right column widget area on front page (default output on items)
	register_sidebar( array(
		'name' => __( 'Front Page Right Column', 'simple-static' ),
		'id' => 'front-page-right-column',
		'description' => __( 'The right column on the front page.', 'simple-static' ),
	) );

	// Right column widget area on the News/Press category
	register_sidebar( array(
		'name' => __( 'News and Press Right Column', 'simple-static' ),
		'id' => 'news-press-right-column',
		'description' => __( 'The right column on News/Press categories.', 'simple-static' ),
		'before_widget' => '<li id="%1$s" class="widget news %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );

	// Right column widget area on the Blog section
	register_sidebar( array(
		'name' => __( 'Blog Right Column', 'simple-static' ),
		'id' => 'blog-right-column',
		'description' => __( 'The right column on the Blog section.', 'simple-static' ),
		'before_widget' => '<li id="%1$s" class="widget blog %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );

	// Right column widget area on Pages
	register_sidebar( array(
		'name' => __( 'Pages Column', 'simple-static' ),
		'id' => 'pages-right-column',
		'description' => __( 'The right column on Pages.', 'simple-static' ),
		'before_widget' => '<li id="%1$s" class="widget pages %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );
	
	// Left column in the footer
	register_sidebar( array(
		'name' => __( 'Footer Left Side', 'simple-static' ),
		'id' => 'footer-left-side',
		'description' => __( 'The left hand side of the footer.', 'simple-static' ),
		'before_widget' => '<li id="%1$s" class="widget footer %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );

	// Right column in the footer
	register_sidebar( array(
		'name' => __( 'Footer Right Column', 'simple-static' ),
		'id' => 'footer-right-column',
		'description' => __( 'The right hand column in the footer.', 'simple-static' ),
		'before_widget' => '<li id="%1$s" class="widget footer %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );
	
	// Right column fallback widget area
	register_sidebar( array(
		'name' => __( 'Right Column Fallback', 'simple-static' ),
		'id' => 'right-column-fallback',
		'description' => __( 'The right column fallback area for those non-posts and pages.', 'simple-static' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2 class="widgettitle">',
		'after_title' => '</h2>',
	) );
?>